@@ -1422,7 +1422,7 @@ Przyjemnej nauki!</translation>
         <source>Scheduled cards for the next days:
 
 </source>
-        <translation>Ilość kart przeznaczonych do powtórki:
+        <translation type="obsolete">Ilość kart przeznaczonych do powtórki:
 
 </translation>
     </message>
@@ -1474,6 +1474,12 @@ Przyjemnej nauki!</translation>
         <source>Days until next repetition:</source>
         <translation type="unfinished">Liczba dni pozostałych do rozpoczęcia powtórki:</translation>
     </message>
+    <message>
+        <source>Scheduled cards for next week:
+
+</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>StatisticsFrm</name>
