@@ -506,7 +506,7 @@ Creating tmp file.</source>
     </message>
     <message>
         <source>Number of grade 0 cards to learn at once:</source>
-        <translation>一次学习0分卡片数量：</translation>
+        <translation type="obsolete">一次学习0分卡片数量：</translation>
     </message>
     <message>
         <source>Note: this is NOT the number of grade 0 cards you want to memorise *per day*</source>
@@ -528,6 +528,10 @@ Creating tmp file.</source>
         <source>Learn new cards in random order</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Number of grade 0 cards to hold in your hand:</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditItemFrm</name>
@@ -1419,7 +1423,7 @@ Happy learning!</source>
         <source>Scheduled cards for the next days:
 
 </source>
-        <translation>今后几天计划的卡片数：
+        <translation type="obsolete">今后几天计划的卡片数：
 
 </translation>
     </message>
@@ -1471,6 +1475,12 @@ Happy learning!</source>
         <source>Days until next repetition:</source>
         <translation type="unfinished">直到下次重复的天数：</translation>
     </message>
+    <message>
+        <source>Scheduled cards for next week:
+
+</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>StatisticsFrm</name>
